get_deployment_clusters

Function get_deployment_clusters 

pub(super) async fn get_deployment_clusters(
    client: &Client,
    deploy_id: &str,
) -> Result<Vec<String>, ConnectionError>
Get cluster names for a staging deployment.

Returns cluster names by resolving cluster IDs via JOIN with mz_catalog.mz_clusters. If a cluster ID exists in _mz_deploy.public.clusters but the cluster was deleted from the catalog, that cluster will be silently omitted from results.