get_deployment_hydration_status

Function get_deployment_hydration_status 

pub(super) async fn get_deployment_hydration_status(
    client: &Client,
    deploy_id: &str,
    allowed_lag_secs: i64,
) -> Result<Vec<ClusterStatusContext>, ConnectionError>
Get detailed hydration and health status for clusters in a staging deployment.

This function checks:

  • Hydration progress for each cluster
  • Wallclock lag to determine if data is fresh
  • Replica health (detecting OOM-looping replicas)

Arguments

  • client - Database client
  • deploy_id - Staging deployment ID
  • allowed_lag_secs - Maximum allowed lag in seconds before marking as “lagging”

Returns

A vector of ClusterStatusContext with full status details for each cluster.