pub(super) async fn get_deployment_objects(
client: &Client,
deploy_id: Option<&str>,
) -> Result<DeploymentSnapshot, ConnectionError>Expand description
Get deployment object records from the database for a specific deployment.
pub(super) async fn get_deployment_objects(
client: &Client,
deploy_id: Option<&str>,
) -> Result<DeploymentSnapshot, ConnectionError>Get deployment object records from the database for a specific deployment.