pub(super) async fn get_schema_deployments(
client: &Client,
deploy_id: Option<&str>,
) -> Result<Vec<SchemaDeploymentRecord>, ConnectionError>Expand description
Get schema deployment records from the database for a specific deployment.
pub(super) async fn get_schema_deployments(
client: &Client,
deploy_id: Option<&str>,
) -> Result<Vec<SchemaDeploymentRecord>, ConnectionError>Get schema deployment records from the database for a specific deployment.